@@ -13,6 +13,7 @@ from celery import current_app
 from celery import states
 from celery.__compat__ import class_property
 from celery._state import get_current_worker_task, _task_stack
+from celery.canvas import subtask
 from celery.datastructures import ExceptionInfo
 from celery.exceptions import MaxRetriesExceededError, RetryTaskError
 from celery.result import EagerResult
@@ -499,9 +500,16 @@ class Task(object):
 
         :param args: Positional arguments to retry with.
         :param kwargs: Keyword arguments to retry with.
-        :keyword exc: Optional exception to raise instead of
-                      :exc:`~celery.exceptions.MaxRetriesExceededError`
-                      when the max restart limit has been exceeded.
+        :keyword exc: Custom exception to report when the max restart
+            limit has been exceeded (default:
+            :exc:`~celery.exceptions.MaxRetriesExceededError`).
+
+            If this argument is set and retry is called while
+            an exception was raised (``sys.exc_info()`` is set)
+            it will attempt to reraise the current exception.
+
+            If no exception was raised it will raise the ``exc``
+            argument provided.
         :keyword countdown: Time in seconds to delay the retry for.
         :keyword eta: Explicit time and date to run the retry at
                       (must be a :class:`~datetime.datetime` instance).
@@ -638,12 +646,11 @@ class Task(object):
         return self._get_app().AsyncResult(task_id, backend=self.backend,
                                            task_name=self.name, **kwargs)
 
-    def subtask(self, *args, **kwargs):
+    def subtask(self, args=None, *starargs, **starkwargs):
         """Returns :class:`~celery.subtask` object for
         this task, wrapping arguments and execution options
         for a single task invocation."""
-        from celery.canvas import subtask
-        return subtask(self, *args, **kwargs)
+        return subtask(self, args, *starargs, **starkwargs)
 
     def s(self, *args, **kwargs):
         """``.s(*a, **k) -> .subtask(a, k)``"""
@@ -758,19 +765,6 @@ class Task(object):
                 not getattr(self, 'disable_error_emails', None):
             self.ErrorMail(self, **kwargs).send(context, exc)
 
-    def execute(self, request, pool, loglevel, logfile, **kwargs):
-        """The method the worker calls to execute the task.
-
-        :param request: A :class:`~celery.worker.job.Request`.
-        :param pool: A task pool.
-        :param loglevel: Current loglevel.
-        :param logfile: Name of the currently used logfile.
-
-        :keyword consumer: The :class:`~celery.worker.consumer.Consumer`.
-
-        """
-        request.execute_using_pool(pool, loglevel, logfile)
-
     def push_request(self, *args, **kwargs):
         self.request_stack.push(Context(*args, **kwargs))
 
@@ -779,6 +773,8 @@ class Task(object):
 
     def __repr__(self):
         """`repr(task)`"""
+        if self.__self__:
+            return '<bound task %s of %r>' % (self.name, self.__self__)
         return '<@task: %s>' % (self.name, )
 
     def _get_request(self):
