@@ -14,6 +14,7 @@ from __future__ import absolute_import
 
 import logging
 import os
+import platform as _platform
 import socket
 import sys
 import warnings
@@ -74,13 +75,15 @@ ARTLINES = [
 BANNER = """\
 celery@%(hostname)s v%(version)s
 
-[Configuration]
-. broker:      %(conninfo)s
-. app:         %(app)s
-. concurrency: %(concurrency)s
-. events:      %(events)s
+%(platform)s
 
-[Queues]
+[config]
+.> broker:      %(conninfo)s
+.> app:         %(app)s
+.> concurrency: %(concurrency)s
+.> events:      %(events)s
+
+[queues]
 %(queues)s
 """
 
@@ -210,11 +213,11 @@ class Worker(configurated):
         print('purge: Erased %d %s from the queue.\n' % (
             count, pluralize(count, 'message')))
 
-    def tasklist(self, include_builtins=True):
-        tasks = self.app.tasks
-        if not include_builtins:
-            tasks = filter(lambda s: not s.startswith('celery.'), tasks)
-        return '\n'.join('  . %s' % task for task in sorted(tasks))
+    def tasklist(self, include_builtins=True, sep='\n', int_='celery.'):
+        return sep.join(
+            '  . %s' % task for task in sorted(self.app.tasks)
+            if (not task.startswith(int_) if not include_builtins else task)
+        )
 
     def extra_info(self):
         if self.loglevel <= logging.INFO:
@@ -248,6 +251,7 @@ class Worker(configurated):
             'version': VERSION_BANNER,
             'conninfo': self.app.connection().as_uri(),
             'concurrency': concurrency,
+            'platform': _platform.platform(),
             'events': events,
             'queues': app.amqp.queues.format(indent=0, indent_first=False),
         }).splitlines()
@@ -353,6 +357,9 @@ else:
 
 def _clone_current_worker():
     if os.fork() == 0:
+        platforms.close_open_fds([
+            sys.__stdin__, sys.__stdout__, sys.__stderr__,
+        ])
         os.execv(sys.executable, [sys.executable] + sys.argv)
 
 
